<?php

/*
 * Copyright 2008 ThinkLeft (thinkleft.com.au)
 * Copyright 2008 ProsePoint (www.prosepoint.org)
 */

module_load_include('inc', 'pp_ed', 'pp_ed.tinymce_popup');

/** Media insert wizard */

function pp_ed_insert_media_page($phase = '', $nid = null) {
  global $user;

  $title = $head = '';  
  if ($phase == 'start' || $phase == '') {
    $output = drupal_get_form('pp_ed_media_start_form');
    $title = t('Insert media');
  }
  else if ($phase == 'upload') {
    $title = t('Upload media');
    if (!module_exists('pp_media')) {
      $output = t('The ProsePoint Media module needs to be enabled to upload media.');
    } 
    elseif (!user_access('create media content')) {
      $output = t('Your account does not have media uploading privileges.');      
    }
    else {
      module_load_include('inc', 'node', 'node.pages');

      $node = array('uid' => $user->uid, 'name' => (isset($user->name) ? $user->name : ''), 'type' => 'media', 'language' => '');
      $output = drupal_get_form('pp_ed_media_upload_form', $node);

      // Check for any errors or drupal_set_messages' and display them
      // ToDo: Need to check anything here? 
      $errors = form_get_errors();
      if (!empty($errors)) {
      }

    }
  }
  else if ($phase == 'browse') {
    $title = t('Browse media');
    if ($view = views_get_view('media_list')) {
      $output = $view->execute_display(null);
      $view->destroy();
    }         
    else {
      drupal_set_message(t('ProsePoint error: Missing view %view', array('%view' => 'media_list')), 'error');
    }
  }
  else if ($phase == 'insert') {    
    $title = $_GET['preset'] ? t('Edit inserted media node') : t('Insert media node');
    // Ensure we have a preselected node
    if (!empty($nid) && is_numeric($nid)) {
      $node = node_load(array('type' => 'media', 'nid' => $nid));
    }
    if ($node->nid) {
      global $base_url;
      $head = '  <script type="text/javascript" src="' . $base_url . '/'. drupal_get_path('module', 'pp_ed') . '/plugins/pp_ed_media/js/insert.js' . '"></script>';
      $form = drupal_get_form('pp_ed_media_insert_form', $node);
      $output = '<div class="pp_ed_startover">' . l(t('Start over'), 'pp_ed/insert/media/start') . '</div>'
                . $form .
                '<div class = "pp_ed_preview_pane"><h3>'.t('Media Preview').'</h3><p id="pp_ed_media_preview">' . $node->default_media . '</p></div>';
    }
    else {
      $output = t('Invalid media selected');
    }
  }
  
  echo _pp_ed_tinymce_popup_wrap($title, $head, $output);
}

function pp_ed_media_start_form($form_state) {
  $form['upload'] = array(
    '#value' => '<p>' . l(t('Upload a new media file'), 'pp_ed/insert/media/upload') . '</p>',
  );
  $form['browse'] = array(
    '#value' => '<p>' . l(t('Browse for a media file'), 'pp_ed/insert/media/browse') . '</p>',
  );
  $form['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'submit',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
  );
  return $form;
}

// The media upload form is just a wrapper around media_node_form, but with some modifications
function pp_ed_media_upload_form(&$form_state, $node) {
  global $user;
  
  $form = node_form($form_state, $node);
  // Dummy up #submit and #validate so filefield doesn't trigger a PHP warning. 
  $form['#submit'] = array();
  $form['#validate'] = array();
  content_form_alter($form, $form_state, 'media_node_form');
  
  // Unset all but the essential fields
  // Rationale: If someone is inserting stuff while editing a story/page node, 
  //   they won't care about authorship, url aliases, menu settings et. al. 
  unset($form['revision_information']);
  unset($form['options']);

  // Change the body from a textarea to a textfield
  $form['body'] = $form['body_field']['body'];
  $form['body']['#type'] = 'textfield';
  $form['body']['#weight'] = 0;
  unset($form['body_field']);
  
  // Some more poking
  $form['#id'] = 'pp_ed_media_upload_form';
  $form['#action'] = url($_GET['q']);
  $form['#validate'][] = 'pp_ed_media_upload_form_validate';
  // DO NOT add 'pp_ed_media_upload_form_submit' as a callback to $form['#submit']
  //   This will cause infinite recursion. 
  $form['buttons']['submit']['#submit'] = array('pp_ed_media_upload_form_submit');
  unset($form['buttons']['preview']);

  // Fill in the author
  $form['author']['#type'] = 'value';
  $form['author']['name']['#type'] = 'value';
  $form['author']['name']['#value'] = $user->name;
  $form['author']['date']['#type'] = 'value';
  
  // Add a cancel button
  $form['buttons']['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'submit',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
    '#weight' => 6,
  );

  return $form;
}

function pp_ed_media_upload_form_validate($form, &$form_state) {  
  node_form_validate($form, $form_state);
}

function pp_ed_media_upload_form_submit($form, &$form_state) {
  // Caution: the following may cause infinite recursion if we're not careful
  //   about what calls this function as a callback
  node_form_submit($form, $form_state);
  // Hijack the redirect to point to our own page
  $form_state['redirect'] = url('pp_ed/insert/media/insert/' . $form_state['nid']);
}

function pp_ed_media_insert_form($form_state, $node) {
  if ($_GET['width'] && is_numeric($_GET['width']))
    $node->field_width[0]['value'] = $_GET['width'];
  if ($_GET['height'] && is_numeric($_GET['height']))
    $node->field_height[0]['value'] = $_GET['height'];
  
  $form = array(
   '#action' => '#',
   '#attributes' => array('onsubmit' => 'pp_ed_media_insert_node(); return false;'),
  );  
  $form['nid'] = array(
    '#type' => 'hidden',
    '#value' => $node->nid,
  );
  $form['title'] = array(
    '#title' => t('Title'),
    '#type' => 'textfield',
    '#description' => t('The title or name of the media'),
    '#default_value' => $_GET['title'] ? $_GET['title'] : $node->title,
  );
  $form['width'] = array(
    '#title' => t('Width'),    
    '#type' => 'textfield', '#value' => $node->field_width[0]['value'],
    '#description' => t('The width of the media file when displayed in a browser (in pixels). '),
    '#size' => 6,
  );
  $form['height'] = array(
    '#title' => t('Height'),    
    '#type' => 'textfield', '#value' => $node->field_height[0]['value'],
    '#description' => t('The height of the media file when displayed in a browser (in pixels). '),
    '#size' => 6,
  );
  $form['caption'] = array(
    '#title' => t('Caption'),
    '#type' => 'textfield',
    '#default_value' => $_GET['caption'],
  );
  $form['alignment'] = array(
    '#title' => t('Alignment'),
    '#type' => 'radios',
    '#options' => array('none' => t('None'), 'left' => t('Left'), 'center' => t('Center'), 'right' => t('Right')),
  );
  $form['alignment']['#default_value'] = array_key_exists($_GET['align'], $form['alignment']['#options']) ? $_GET['align'] : 'none';
  $form['submit'] = array(
    '#value' => t('Insert into post'),
    '#type' => 'submit',
  );
  $form['cancel'] = array(
    '#value' => t('Cancel'),
    '#type' => 'button',
    '#attributes' => array('onclick' => 'tinyMCEPopup.close(); return false;'),
  );
  $node->default_media = '<div class="pp_media">' . pp_media_render($node) . '</div>';
  return $form;
}


